@@ -11,7 +11,7 @@ use Scalar::Util;
 use Scope::Guard;
 use Storable;
 
-our $VERSION = '2.60';
+our $VERSION = '2.73';
 
 XSLoader::load 'autobox', $VERSION;
 
@@ -80,31 +80,30 @@ sub _generate_class($) {
     # rather than in the ISA hierarchy with its attendant AUTOLOAD-related overhead
     if (@$isa == 1) {
         my $class = $isa->[0];
-        _universalize($class); # nop if it's already been universalized
+        _make_class_accessor($class); # nop if it's already been universalized
         return $class;
     }
 
     my $key = Storable::freeze($isa);
 
     return $CLASS_CACHE->{$key} ||= do {
-        my $class = sprintf('autobox::shim::<%d>', ++$SEQ);
+        my $class = sprintf('autobox::_shim_%d_', ++$SEQ);
         my $synthetic_class_isa = _get_isa($class); # i.e. autovivify
 
         @$synthetic_class_isa = @$isa;
-        _universalize($class);
+        _make_class_accessor($class);
         $class;
     };
 }
 
-# make can() and isa() work as expected for autoboxed values by calling the method on their associated class
-sub _universalize ($) {
+# expose the autobox class (for can, isa &c.)
+# https://rt.cpan.org/Ticket/Display.html?id=55565
+sub _make_class_accessor ($) {
     my $class = shift;
     return unless (defined $class);
     {
         no strict 'refs';
-	# don't interfere with STRING->can and STRING->isa: https://rt.cpan.org/Ticket/Display.html?id=55565
-        *{"$class\::autobox_can"} = sub { shift; $class->can(@_) } unless (*{"$class\::autobox_can"}{CODE});
-        *{"$class\::autobox_isa"} = sub { shift; $class->isa(@_) } unless (*{"$class\::autobox_isa"}{CODE});
+        *{"$class\::autobox_class"} = sub { $class } unless (*{"$class\::autobox_class"}{CODE});
     }
 }
 
@@ -296,7 +295,7 @@ sub import {
     #
     # It needs to be set unconditionally because it may have been unset in unimport
 
-    $^H |= 0x120000; # set HINT_LOCALIZE_HH + an unused bit to work around a %^H bug
+    $^H |= 0x80020000; # set HINT_LOCALIZE_HH + an unused bit to work around a %^H bug
 
     # install the specified bindings in the current scope
     _install($bindings);
@@ -391,7 +390,7 @@ sub unimport {
     if (%$bindings) {
         _install($bindings);
     } else { # remove all traces of autobox from the current scope
-        $^H &= ~0x120000; # unset HINT_LOCALIZE_HH + the additional bit
+        $^H &= ~0x80020000; # unset HINT_LOCALIZE_HH + the additional bit
         delete $^H{autobox};
         delete $^H{autobox_scope};
         delete $^H{autobox_leave}; # triggers the leave handler
